@@ -4,21 +4,21 @@
 pub struct PublisherAccount {
     /// Resource name of this account.
     /// Format is accounts/{publisher_id}.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
     /// The unique ID by which this publisher account can be identified
     /// in the API requests (for example, pub-1234567890).
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub publisher_id: ::prost::alloc::string::String,
     /// The time zone that is used in reports that are generated for this account.
     /// The value is a time-zone ID as specified by the CLDR project,
     /// for example, "America/Los_Angeles".
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub reporting_time_zone: ::prost::alloc::string::String,
     /// Currency code of the earning-related metrics, which is the 3-letter code
     /// defined in ISO 4217. The daily average rate is used for the currency
     /// conversion.
-    #[prost(string, tag = "4")]
+    #[prost(string, tag="4")]
     pub currency_code: ::prost::alloc::string::String,
 }
 /// The specification for generating an AdMob Network report.
@@ -60,32 +60,32 @@ pub struct PublisherAccount {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct NetworkReportSpec {
     /// The date range for which the report is generated.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub date_range: ::core::option::Option<DateRange>,
     /// List of dimensions of the report. The value combination of these dimensions
     /// determines the row of the report. If no dimensions are specified, the
     /// report returns a single row of requested metrics for the entire account.
-    #[prost(enumeration = "network_report_spec::Dimension", repeated, tag = "2")]
+    #[prost(enumeration="network_report_spec::Dimension", repeated, tag="2")]
     pub dimensions: ::prost::alloc::vec::Vec<i32>,
     /// List of metrics of the report. A report must specify at least one metric.
-    #[prost(enumeration = "network_report_spec::Metric", repeated, tag = "3")]
+    #[prost(enumeration="network_report_spec::Metric", repeated, tag="3")]
     pub metrics: ::prost::alloc::vec::Vec<i32>,
     /// Describes which report rows to match based on their dimension values.
-    #[prost(message, repeated, tag = "4")]
+    #[prost(message, repeated, tag="4")]
     pub dimension_filters: ::prost::alloc::vec::Vec<network_report_spec::DimensionFilter>,
     /// Describes the sorting of report rows. The order of the condition in the
     /// list defines its precedence; the earlier the condition, the higher its
     /// precedence. If no sort conditions are specified, the row ordering is
     /// undefined.
-    #[prost(message, repeated, tag = "5")]
+    #[prost(message, repeated, tag="5")]
     pub sort_conditions: ::prost::alloc::vec::Vec<network_report_spec::SortCondition>,
     /// Localization settings of the report.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub localization_settings: ::core::option::Option<LocalizationSettings>,
     /// Maximum number of report data rows to return. If the value is not set, the
     /// API returns as many rows as possible, up to 100000. Acceptable values are
     /// 1-100000, inclusive. Any other values are treated as 100000.
-    #[prost(int32, tag = "7")]
+    #[prost(int32, tag="7")]
     pub max_report_rows: i32,
     /// A report time zone. Accepts an IANA TZ name values, such as
     /// "America/Los_Angeles."  If no time zone is defined, the account default
@@ -93,7 +93,7 @@ pub struct NetworkReportSpec {
     ///
     /// **Warning:** The "America/Los_Angeles" is the only supported value at
     /// the moment.
-    #[prost(string, tag = "8")]
+    #[prost(string, tag="8")]
     pub time_zone: ::prost::alloc::string::String,
 }
 /// Nested message and enum types in `NetworkReportSpec`.
@@ -102,10 +102,10 @@ pub mod network_report_spec {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct DimensionFilter {
         /// Applies the filter criterion to the specified dimension.
-        #[prost(enumeration = "Dimension", tag = "1")]
+        #[prost(enumeration="Dimension", tag="1")]
         pub dimension: i32,
         /// Filter operator to be applied.
-        #[prost(oneof = "dimension_filter::Operator", tags = "2")]
+        #[prost(oneof="dimension_filter::Operator", tags="2")]
         pub operator: ::core::option::Option<dimension_filter::Operator>,
     }
     /// Nested message and enum types in `DimensionFilter`.
@@ -115,7 +115,7 @@ pub mod network_report_spec {
         pub enum Operator {
             /// Matches a row if its value for the specified dimension is in one of the
             /// values specified in this condition.
-            #[prost(message, tag = "2")]
+            #[prost(message, tag="2")]
             MatchesAny(super::super::StringList),
         }
     }
@@ -123,10 +123,10 @@ pub mod network_report_spec {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct SortCondition {
         /// Sorting order of the dimension or metric.
-        #[prost(enumeration = "super::SortOrder", tag = "3")]
+        #[prost(enumeration="super::SortOrder", tag="3")]
         pub order: i32,
         /// Identifies which values to sort on.
-        #[prost(oneof = "sort_condition::SortOn", tags = "1, 2")]
+        #[prost(oneof="sort_condition::SortOn", tags="1, 2")]
         pub sort_on: ::core::option::Option<sort_condition::SortOn>,
     }
     /// Nested message and enum types in `SortCondition`.
@@ -135,10 +135,10 @@ pub mod network_report_spec {
         #[derive(Clone, PartialEq, ::prost::Oneof)]
         pub enum SortOn {
             /// Sort by the specified dimension.
-            #[prost(enumeration = "super::Dimension", tag = "1")]
+            #[prost(enumeration="super::Dimension", tag="1")]
             Dimension(i32),
             /// Sort by the specified metric.
-            #[prost(enumeration = "super::Metric", tag = "2")]
+            #[prost(enumeration="super::Metric", tag="2")]
             Metric(i32),
         }
     }
@@ -268,32 +268,32 @@ pub mod network_report_spec {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct MediationReportSpec {
     /// The date range for which the report is generated.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub date_range: ::core::option::Option<DateRange>,
     /// List of dimensions of the report. The value combination of these dimensions
     /// determines the row of the report. If no dimensions are specified, the
     /// report returns a single row of requested metrics for the entire account.
-    #[prost(enumeration = "mediation_report_spec::Dimension", repeated, tag = "2")]
+    #[prost(enumeration="mediation_report_spec::Dimension", repeated, tag="2")]
     pub dimensions: ::prost::alloc::vec::Vec<i32>,
     /// List of metrics of the report. A report must specify at least one metric.
-    #[prost(enumeration = "mediation_report_spec::Metric", repeated, tag = "3")]
+    #[prost(enumeration="mediation_report_spec::Metric", repeated, tag="3")]
     pub metrics: ::prost::alloc::vec::Vec<i32>,
     /// Describes which report rows to match based on their dimension values.
-    #[prost(message, repeated, tag = "4")]
+    #[prost(message, repeated, tag="4")]
     pub dimension_filters: ::prost::alloc::vec::Vec<mediation_report_spec::DimensionFilter>,
     /// Describes the sorting of report rows. The order of the condition in the
     /// list defines its precedence; the earlier the condition, the higher its
     /// precedence. If no sort conditions are specified, the row ordering is
     /// undefined.
-    #[prost(message, repeated, tag = "5")]
+    #[prost(message, repeated, tag="5")]
     pub sort_conditions: ::prost::alloc::vec::Vec<mediation_report_spec::SortCondition>,
     /// Localization settings of the report.
-    #[prost(message, optional, tag = "6")]
+    #[prost(message, optional, tag="6")]
     pub localization_settings: ::core::option::Option<LocalizationSettings>,
     /// Maximum number of report data rows to return. If the value is not set, the
     /// API returns as many rows as possible, up to 100000. Acceptable values are
     /// 1-100000, inclusive. Any other values are treated as 100000.
-    #[prost(int32, tag = "7")]
+    #[prost(int32, tag="7")]
     pub max_report_rows: i32,
     /// A report time zone. Accepts an IANA TZ name values, such as
     /// "America/Los_Angeles."  If no time zone is defined, the account default
@@ -301,7 +301,7 @@ pub struct MediationReportSpec {
     ///
     /// **Warning:** The "America/Los_Angeles" is the only supported value at
     /// the moment.
-    #[prost(string, tag = "8")]
+    #[prost(string, tag="8")]
     pub time_zone: ::prost::alloc::string::String,
 }
 /// Nested message and enum types in `MediationReportSpec`.
@@ -310,10 +310,10 @@ pub mod mediation_report_spec {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct DimensionFilter {
         /// Applies the filter criterion to the specified dimension.
-        #[prost(enumeration = "Dimension", tag = "1")]
+        #[prost(enumeration="Dimension", tag="1")]
         pub dimension: i32,
         /// Filter operator to be applied.
-        #[prost(oneof = "dimension_filter::Operator", tags = "2")]
+        #[prost(oneof="dimension_filter::Operator", tags="2")]
         pub operator: ::core::option::Option<dimension_filter::Operator>,
     }
     /// Nested message and enum types in `DimensionFilter`.
@@ -323,7 +323,7 @@ pub mod mediation_report_spec {
         pub enum Operator {
             /// Matches a row if its value for the specified dimension is in one of the
             /// values specified in this condition.
-            #[prost(message, tag = "2")]
+            #[prost(message, tag="2")]
             MatchesAny(super::super::StringList),
         }
     }
@@ -331,10 +331,10 @@ pub mod mediation_report_spec {
     #[derive(Clone, PartialEq, ::prost::Message)]
     pub struct SortCondition {
         /// Sorting order of the dimension or metric.
-        #[prost(enumeration = "super::SortOrder", tag = "3")]
+        #[prost(enumeration="super::SortOrder", tag="3")]
         pub order: i32,
         /// Identifies which values to sort on.
-        #[prost(oneof = "sort_condition::SortOn", tags = "1, 2")]
+        #[prost(oneof="sort_condition::SortOn", tags="1, 2")]
         pub sort_on: ::core::option::Option<sort_condition::SortOn>,
     }
     /// Nested message and enum types in `SortCondition`.
@@ -343,10 +343,10 @@ pub mod mediation_report_spec {
         #[derive(Clone, PartialEq, ::prost::Oneof)]
         pub enum SortOn {
             /// Sort by the specified dimension.
-            #[prost(enumeration = "super::Dimension", tag = "1")]
+            #[prost(enumeration="super::Dimension", tag="1")]
             Dimension(i32),
             /// Sort by the specified metric.
-            #[prost(enumeration = "super::Metric", tag = "2")]
+            #[prost(enumeration="super::Metric", tag="2")]
             Metric(i32),
         }
     }
@@ -440,19 +440,13 @@ pub mod mediation_report_spec {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ReportRow {
     /// Map of dimension values in a row, with keys as enum name of the dimensions.
-    #[prost(btree_map = "string, message", tag = "1")]
-    pub dimension_values: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        report_row::DimensionValue,
-    >,
+    #[prost(btree_map="string, message", tag="1")]
+    pub dimension_values: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, report_row::DimensionValue>,
     /// Map of metric values in a row, with keys as enum name of the metrics. If
     /// a metric being requested has no value returned, the map will not include
     /// it.
-    #[prost(btree_map = "string, message", tag = "2")]
-    pub metric_values: ::prost::alloc::collections::BTreeMap<
-        ::prost::alloc::string::String,
-        report_row::MetricValue,
-    >,
+    #[prost(btree_map="string, message", tag="2")]
+    pub metric_values: ::prost::alloc::collections::BTreeMap<::prost::alloc::string::String, report_row::MetricValue>,
 }
 /// Nested message and enum types in `ReportRow`.
 pub mod report_row {
@@ -461,11 +455,11 @@ pub mod report_row {
     pub struct DimensionValue {
         /// Dimension value in the format specified in the report's spec Dimension
         /// enum.
-        #[prost(string, tag = "1")]
+        #[prost(string, tag="1")]
         pub value: ::prost::alloc::string::String,
         /// The localized string representation of the value. If unspecified, the
         /// display label should be derived from the value.
-        #[prost(string, tag = "2")]
+        #[prost(string, tag="2")]
         pub display_label: ::prost::alloc::string::String,
     }
     /// Representation of a metric value.
@@ -473,7 +467,7 @@ pub mod report_row {
     pub struct MetricValue {
         /// Metric value in the format specified in the report's spec Metric enum
         /// name.
-        #[prost(oneof = "metric_value::Value", tags = "1, 2, 3")]
+        #[prost(oneof="metric_value::Value", tags="1, 2, 3")]
         pub value: ::core::option::Option<metric_value::Value>,
     }
     /// Nested message and enum types in `MetricValue`.
@@ -483,15 +477,15 @@ pub mod report_row {
         #[derive(Clone, PartialEq, ::prost::Oneof)]
         pub enum Value {
             /// Metric integer value.
-            #[prost(int64, tag = "1")]
+            #[prost(int64, tag="1")]
             IntegerValue(i64),
             /// Double precision (approximate) decimal values. Rates are from 0 to 1.
-            #[prost(double, tag = "2")]
+            #[prost(double, tag="2")]
             DoubleValue(f64),
             /// Amount in micros. One million is equivalent to one unit. Currency value
             /// is in the unit (USD, EUR or other) specified by the request.
             /// For example, $6.50 whould be represented as 6500000 micros.
-            #[prost(int64, tag = "3")]
+            #[prost(int64, tag="3")]
             MicrosValue(i64),
         }
     }
@@ -500,10 +494,10 @@ pub mod report_row {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ReportWarning {
     /// Type of the warning.
-    #[prost(enumeration = "report_warning::Type", tag = "1")]
+    #[prost(enumeration="report_warning::Type", tag="1")]
     pub r#type: i32,
     /// Describes the details of the warning message, in English.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub description: ::prost::alloc::string::String,
 }
 /// Nested message and enum types in `ReportWarning`.
@@ -541,15 +535,15 @@ pub mod report_warning {
 pub struct ReportHeader {
     /// The date range for which the report is generated. This is identical to the
     /// range specified in the report request.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub date_range: ::core::option::Option<DateRange>,
     /// Localization settings of the report. This is identical to the settings
     /// in the report request.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub localization_settings: ::core::option::Option<LocalizationSettings>,
     /// The report time zone. The value is a time-zone ID as specified by the CLDR
     /// project, for example, "America/Los_Angeles".
-    #[prost(string, tag = "3")]
+    #[prost(string, tag="3")]
     pub reporting_time_zone: ::prost::alloc::string::String,
 }
 /// Groups data available after report generation, for example, warnings and row
@@ -557,13 +551,13 @@ pub struct ReportHeader {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ReportFooter {
     /// Warnings associated with generation of the report.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub warnings: ::prost::alloc::vec::Vec<ReportWarning>,
     /// Total number of rows that matched the request.
     ///
     /// Warning: This count does NOT always match the number of rows in the
     /// response. Do not make that assumption when processing the response.
-    #[prost(int64, tag = "2")]
+    #[prost(int64, tag="2")]
     pub matching_row_count: i64,
 }
 /// Specification of a single date range. Both dates are inclusive.
@@ -571,11 +565,11 @@ pub struct ReportFooter {
 pub struct DateRange {
     /// Start date of the date range, inclusive. Must be less than or equal to the
     /// end date.
-    #[prost(message, optional, tag = "1")]
+    #[prost(message, optional, tag="1")]
     pub start_date: ::core::option::Option<super::super::super::r#type::Date>,
     /// End date of the date range, inclusive. Must be greater than or equal to the
     /// start date.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub end_date: ::core::option::Option<super::super::super::r#type::Date>,
 }
 /// Localization settings for reports, such as currency and language. It affects
@@ -585,19 +579,19 @@ pub struct LocalizationSettings {
     /// Currency code of the earning related metrics, which is the 3-letter code
     /// defined in ISO 4217. The daily average rate is used for the currency
     /// conversion. Defaults to the account currency code if unspecified.
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub currency_code: ::prost::alloc::string::String,
     /// Language used for any localized text, such as some dimension value display
     /// labels. The language tag defined in the IETF BCP47. Defaults to 'en-US' if
     /// unspecified.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub language_code: ::prost::alloc::string::String,
 }
 /// List of string values.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct StringList {
     /// The string values.
-    #[prost(string, repeated, tag = "1")]
+    #[prost(string, repeated, tag="1")]
     pub values: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
 }
 /// The sorting order.
@@ -616,7 +610,7 @@ pub enum SortOrder {
 pub struct GetPublisherAccountRequest {
     /// Resource name of the publisher account to retrieve.
     /// Example: accounts/pub-9876543210987654
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub name: ::prost::alloc::string::String,
 }
 /// Request to retrieve the AdMob publisher account accessible with the client
@@ -624,23 +618,23 @@ pub struct GetPublisherAccountRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListPublisherAccountsRequest {
     /// Maximum number of accounts to return.
-    #[prost(int32, tag = "1")]
+    #[prost(int32, tag="1")]
     pub page_size: i32,
     /// The value returned by the last `ListPublisherAccountsResponse`; indicates
     /// that this is a continuation of a prior `ListPublisherAccounts` call, and
     /// that the system should return the next page of data.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub page_token: ::prost::alloc::string::String,
 }
 /// Response for the publisher account list request.
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct ListPublisherAccountsResponse {
     /// Publisher that the client credentials can access.
-    #[prost(message, repeated, tag = "1")]
+    #[prost(message, repeated, tag="1")]
     pub account: ::prost::alloc::vec::Vec<PublisherAccount>,
     /// If not empty, indicates that there might be more accounts for the request;
     /// you must pass this value in a new `ListPublisherAccountsRequest`.
-    #[prost(string, tag = "2")]
+    #[prost(string, tag="2")]
     pub next_page_token: ::prost::alloc::string::String,
 }
 /// Request to generate an AdMob Mediation report.
@@ -648,10 +642,10 @@ pub struct ListPublisherAccountsResponse {
 pub struct GenerateMediationReportRequest {
     /// Resource name of the account to generate the report for.
     /// Example: accounts/pub-9876543210987654
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Network report specification.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub report_spec: ::core::option::Option<MediationReportSpec>,
 }
 /// The streaming response for the AdMob Mediation report where the first
@@ -692,10 +686,7 @@ pub struct GenerateMediationReportRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenerateMediationReportResponse {
     /// Each stream response message contains one type of payload.
-    #[prost(
-        oneof = "generate_mediation_report_response::Payload",
-        tags = "1, 2, 3"
-    )]
+    #[prost(oneof="generate_mediation_report_response::Payload", tags="1, 2, 3")]
     pub payload: ::core::option::Option<generate_mediation_report_response::Payload>,
 }
 /// Nested message and enum types in `GenerateMediationReportResponse`.
@@ -705,14 +696,14 @@ pub mod generate_mediation_report_response {
     pub enum Payload {
         /// Report generation settings that describes the report contents, such as
         /// the report date range and localization settings.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Header(super::ReportHeader),
         /// Actual report data.
-        #[prost(message, tag = "2")]
+        #[prost(message, tag="2")]
         Row(super::ReportRow),
         /// Additional information about the generated report, such as warnings about
         /// the data.
-        #[prost(message, tag = "3")]
+        #[prost(message, tag="3")]
         Footer(super::ReportFooter),
     }
 }
@@ -721,10 +712,10 @@ pub mod generate_mediation_report_response {
 pub struct GenerateNetworkReportRequest {
     /// Resource name of the account to generate the report for.
     /// Example: accounts/pub-9876543210987654
-    #[prost(string, tag = "1")]
+    #[prost(string, tag="1")]
     pub parent: ::prost::alloc::string::String,
     /// Network report specification.
-    #[prost(message, optional, tag = "2")]
+    #[prost(message, optional, tag="2")]
     pub report_spec: ::core::option::Option<NetworkReportSpec>,
 }
 /// The streaming response for the AdMob Network report where the first response
@@ -765,7 +756,7 @@ pub struct GenerateNetworkReportRequest {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct GenerateNetworkReportResponse {
     /// Each stream response message contains one type of payload.
-    #[prost(oneof = "generate_network_report_response::Payload", tags = "1, 2, 3")]
+    #[prost(oneof="generate_network_report_response::Payload", tags="1, 2, 3")]
     pub payload: ::core::option::Option<generate_network_report_response::Payload>,
 }
 /// Nested message and enum types in `GenerateNetworkReportResponse`.
@@ -775,23 +766,23 @@ pub mod generate_network_report_response {
     pub enum Payload {
         /// Report generation settings that describes the report contents, such as
         /// the report date range and localization settings.
-        #[prost(message, tag = "1")]
+        #[prost(message, tag="1")]
         Header(super::ReportHeader),
         /// Actual report data.
-        #[prost(message, tag = "2")]
+        #[prost(message, tag="2")]
         Row(super::ReportRow),
         /// Additional information about the generated report, such as warnings about
         /// the data.
-        #[prost(message, tag = "3")]
+        #[prost(message, tag="3")]
         Footer(super::ReportFooter),
     }
 }
-#[doc = r" Generated client implementations."]
+/// Generated client implementations.
 pub mod ad_mob_api_client {
     #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
-    #[doc = " The AdMob API allows AdMob publishers programmatically get information about"]
-    #[doc = " their AdMob account."]
+    /// The AdMob API allows AdMob publishers programmatically get information about
+    /// their AdMob account.
     #[derive(Debug, Clone)]
     pub struct AdMobApiClient<T> {
         inner: tonic::client::Grpc<T>,
@@ -799,8 +790,8 @@ pub mod ad_mob_api_client {
     impl<T> AdMobApiClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
+        T::ResponseBody: Default + Body<Data = Bytes> + Send + 'static,
         <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
@@ -819,104 +810,122 @@ pub mod ad_mob_api_client {
                     <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
                 >,
             >,
-            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
-                Into<StdError> + Send + Sync,
+            <T as tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+            >>::Error: Into<StdError> + Send + Sync,
         {
             AdMobApiClient::new(InterceptedService::new(inner, interceptor))
         }
-        #[doc = r" Compress requests with `gzip`."]
-        #[doc = r""]
-        #[doc = r" This requires the server to support it otherwise it might respond with an"]
-        #[doc = r" error."]
+        /// Compress requests with `gzip`.
+        ///
+        /// This requires the server to support it otherwise it might respond with an
+        /// error.
+        #[must_use]
         pub fn send_gzip(mut self) -> Self {
             self.inner = self.inner.send_gzip();
             self
         }
-        #[doc = r" Enable decompressing responses with `gzip`."]
+        /// Enable decompressing responses with `gzip`.
+        #[must_use]
         pub fn accept_gzip(mut self) -> Self {
             self.inner = self.inner.accept_gzip();
             self
         }
-        #[doc = " Gets information about the specified AdMob publisher account."]
+        /// Gets information about the specified AdMob publisher account.
         pub async fn get_publisher_account(
             &mut self,
             request: impl tonic::IntoRequest<super::GetPublisherAccountRequest>,
         ) -> Result<tonic::Response<super::PublisherAccount>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.ads.admob.v1.AdMobApi/GetPublisherAccount",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Lists the AdMob publisher account accessible with the client credential."]
-        #[doc = " Currently, all credentials have access to at most one AdMob account."]
+        /// Lists the AdMob publisher account accessible with the client credential.
+        /// Currently, all credentials have access to at most one AdMob account.
         pub async fn list_publisher_accounts(
             &mut self,
             request: impl tonic::IntoRequest<super::ListPublisherAccountsRequest>,
-        ) -> Result<tonic::Response<super::ListPublisherAccountsResponse>, tonic::Status> {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+        ) -> Result<
+                tonic::Response<super::ListPublisherAccountsResponse>,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.ads.admob.v1.AdMobApi/ListPublisherAccounts",
             );
             self.inner.unary(request.into_request(), path, codec).await
         }
-        #[doc = " Generates an AdMob Network report based on the provided report"]
-        #[doc = " specification."]
+        /// Generates an AdMob Network report based on the provided report
+        /// specification.
         pub async fn generate_network_report(
             &mut self,
             request: impl tonic::IntoRequest<super::GenerateNetworkReportRequest>,
         ) -> Result<
-            tonic::Response<tonic::codec::Streaming<super::GenerateNetworkReportResponse>>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<
+                    tonic::codec::Streaming<super::GenerateNetworkReportResponse>,
+                >,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.ads.admob.v1.AdMobApi/GenerateNetworkReport",
             );
-            self.inner
-                .server_streaming(request.into_request(), path, codec)
-                .await
+            self.inner.server_streaming(request.into_request(), path, codec).await
         }
-        #[doc = " Generates an AdMob Mediation report based on the provided report"]
-        #[doc = " specification."]
+        /// Generates an AdMob Mediation report based on the provided report
+        /// specification.
         pub async fn generate_mediation_report(
             &mut self,
             request: impl tonic::IntoRequest<super::GenerateMediationReportRequest>,
         ) -> Result<
-            tonic::Response<tonic::codec::Streaming<super::GenerateMediationReportResponse>>,
-            tonic::Status,
-        > {
-            self.inner.ready().await.map_err(|e| {
-                tonic::Status::new(
-                    tonic::Code::Unknown,
-                    format!("Service was not ready: {}", e.into()),
-                )
-            })?;
+                tonic::Response<
+                    tonic::codec::Streaming<super::GenerateMediationReportResponse>,
+                >,
+                tonic::Status,
+            > {
+            self.inner
+                .ready()
+                .await
+                .map_err(|e| {
+                    tonic::Status::new(
+                        tonic::Code::Unknown,
+                        format!("Service was not ready: {}", e.into()),
+                    )
+                })?;
             let codec = tonic::codec::ProstCodec::default();
             let path = http::uri::PathAndQuery::from_static(
                 "/google.ads.admob.v1.AdMobApi/GenerateMediationReport",
             );
-            self.inner
-                .server_streaming(request.into_request(), path, codec)
-                .await
+            self.inner.server_streaming(request.into_request(), path, codec).await
         }
     }
 }
